<?php
/**
 * Locale API: WP_Locale class
 *
 * @package WordPress
 * @subpackage i18n
 * @since 4.6.0
 */

class WP_Locale {
	public $weekday;

	public $weekday_initial;
	public $weekday_abbrev;
	public $start_of_week;
	public $month;
	public $month_genitive;

	public $month_abbrev;
	public $meridiem;
	public $text_direction = 'ltr';

	public $number_format;
	public function __construct() {
		$this->init();
		$this->register_globals();
	}

	public function init() {
		// The Weekdays
		$this->weekday[0] = /* translators: weekday */ __('Duminica');
		$this->weekday[1] = /* translators: weekday */ __('Luni');
		$this->weekday[2] = /* translators: weekday */ __('Marti');
		$this->weekday[3] = /* translators: weekday */ __('Miercuri');
		$this->weekday[4] = /* translators: weekday */ __('Joi');
		$this->weekday[5] = /* translators: weekday */ __('Vineri');
		$this->weekday[6] = /* translators: weekday */ __('Sambata');

		// The first letter of each day.
		$this->weekday_initial[ __( 'Duminica' ) ]    = /* translators: one-letter abbreviation of the weekday */ _x( 'S', 'Sunday initial' );
		$this->weekday_initial[ __( 'Luni' ) ]    = /* translators: one-letter abbreviation of the weekday */ _x( 'M', 'Monday initial' );
		$this->weekday_initial[ __( 'Marti' ) ]   = /* translators: one-letter abbreviation of the weekday */ _x( 'T', 'Tuesday initial' );
		$this->weekday_initial[ __( 'Miercuri' ) ] = /* translators: one-letter abbreviation of the weekday */ _x( 'W', 'Wednesday initial' );
		$this->weekday_initial[ __( 'Joi' ) ]  = /* translators: one-letter abbreviation of the weekday */ _x( 'T', 'Thursday initial' );
		$this->weekday_initial[ __( 'Vineri' ) ]    = /* translators: one-letter abbreviation of the weekday */ _x( 'F', 'Friday initial' );
		$this->weekday_initial[ __( 'Sambata' ) ]  = /* translators: one-letter abbreviation of the weekday */ _x( 'S', 'Saturday initial' );

		// Abbreviations for each day.
		$this->weekday_abbrev[__('Duminica')]    = /* translators: three-letter abbreviation of the weekday */ __('Sun');
		$this->weekday_abbrev[__('Luni')]    = /* translators: three-letter abbreviation of the weekday */ __('Mon');
		$this->weekday_abbrev[__('Marti')]   = /* translators: three-letter abbreviation of the weekday */ __('Tue');
		$this->weekday_abbrev[__('Miercuri')] = /* translators: three-letter abbreviation of the weekday */ __('Wed');
		$this->weekday_abbrev[__('Joi')]  = /* translators: three-letter abbreviation of the weekday */ __('Thu');
		$this->weekday_abbrev[__('Vineri')]    = /* translators: three-letter abbreviation of the weekday */ __('Fri');
		$this->weekday_abbrev[__('Sambata')]  = /* translators: three-letter abbreviation of the weekday */ __('Sat');

		// The Months
		$this->month['01'] = /* translators: month name */ __( 'Ianuarie' );
		$this->month['02'] = /* translators: month name */ __( 'Februarie' );
		$this->month['03'] = /* translators: month name */ __( 'Martie' );
		$this->month['04'] = /* translators: month name */ __( 'Aprilie' );
		$this->month['05'] = /* translators: month name */ __( 'Mai' );
		$this->month['06'] = /* translators: month name */ __( 'Iunie' );
		$this->month['07'] = /* translators: month name */ __( 'Iulie' );
		$this->month['08'] = /* translators: month name */ __( 'August' );
		$this->month['09'] = /* translators: month name */ __( 'Septembrie' );
		$this->month['10'] = /* translators: month name */ __( 'Octombrie' );
		$this->month['11'] = /* translators: month name */ __( 'Noiembrie' );
		$this->month['12'] = /* translators: month name */ __( 'Decembrie' );

		// The Months, genitive
		$this->month_genitive['01'] = /* translators: month name, genitive */ _x( 'Ianuarie', 'genitive' );
		$this->month_genitive['02'] = /* translators: month name, genitive */ _x( 'Februarie', 'genitive' );
		$this->month_genitive['03'] = /* translators: month name, genitive */ _x( 'Martie', 'genitive' );
		$this->month_genitive['04'] = /* translators: month name, genitive */ _x( 'Aprilie', 'genitive' );
		$this->month_genitive['05'] = /* translators: month name, genitive */ _x( 'Mai', 'genitive' );
		$this->month_genitive['06'] = /* translators: month name, genitive */ _x( 'Iunie', 'genitive' );
		$this->month_genitive['07'] = /* translators: month name, genitive */ _x( 'Iulie', 'genitive' );
		$this->month_genitive['08'] = /* translators: month name, genitive */ _x( 'August', 'genitive' );
		$this->month_genitive['09'] = /* translators: month name, genitive */ _x( 'Septembrie', 'genitive' );
		$this->month_genitive['10'] = /* translators: month name, genitive */ _x( 'Octombrie', 'genitive' );
		$this->month_genitive['11'] = /* translators: month name, genitive */ _x( 'Noiembrie', 'genitive' );
		$this->month_genitive['12'] = /* translators: month name, genitive */ _x( 'Decembrie', 'genitive' );

		// Abbreviations for each month.
		$this->month_abbrev[ __( 'Ianuarie' ) ]   = /* translators: three-letter abbreviation of the month */ _x( 'Jan', 'January abbreviation' );
		$this->month_abbrev[ __( 'Februarie' ) ]  = /* translators: three-letter abbreviation of the month */ _x( 'Feb', 'February abbreviation' );
		$this->month_abbrev[ __( 'Martie' ) ]     = /* translators: three-letter abbreviation of the month */ _x( 'Mar', 'March abbreviation' );
		$this->month_abbrev[ __( 'Aprilie' ) ]     = /* translators: three-letter abbreviation of the month */ _x( 'Apr', 'April abbreviation' );
		$this->month_abbrev[ __( 'Mai' ) ]       = /* translators: three-letter abbreviation of the month */ _x( 'May', 'May abbreviation' );
		$this->month_abbrev[ __( 'Iunie' ) ]      = /* translators: three-letter abbreviation of the month */ _x( 'Jun', 'June abbreviation' );
		$this->month_abbrev[ __( 'Iulie' ) ]      = /* translators: three-letter abbreviation of the month */ _x( 'Jul', 'July abbreviation' );
		$this->month_abbrev[ __( 'August' ) ]    = /* translators: three-letter abbreviation of the month */ _x( 'Aug', 'August abbreviation' );
		$this->month_abbrev[ __( 'Septembrie' ) ] = /* translators: three-letter abbreviation of the month */ _x( 'Sep', 'September abbreviation' );
		$this->month_abbrev[ __( 'Octombrie' ) ]   = /* translators: three-letter abbreviation of the month */ _x( 'Oct', 'October abbreviation' );
		$this->month_abbrev[ __( 'Noiembrie' ) ]  = /* translators: three-letter abbreviation of the month */ _x( 'Nov', 'November abbreviation' );
		$this->month_abbrev[ __( 'Decembrie' ) ]  = /* translators: three-letter abbreviation of the month */ _x( 'Dec', 'December abbreviation' );

		// The Meridiems
		$this->meridiem['am'] = __('am');
		$this->meridiem['pm'] = __('pm');
		$this->meridiem['AM'] = __('AM');
		$this->meridiem['PM'] = __('PM');

		// Numbers formatting
		// See https://secure.php.net/number_format

		/* translators: $thousands_sep argument for https://secure.php.net/number_format, default is , */
		$thousands_sep = __( 'number_format_thousands_sep' );

		if ( version_compare( PHP_VERSION, '5.4', '>=' ) ) {
			// Replace space with a non-breaking space to avoid wrapping.
			$thousands_sep = str_replace( ' ', '&nbsp;', $thousands_sep );
		} else {
			// PHP < 5.4.0 does not support multiple bytes in thousands separator.
			$thousands_sep = str_replace( array( '&nbsp;', '&#160;' ), ' ', $thousands_sep );
		}

		$this->number_format['thousands_sep'] = ( 'number_format_thousands_sep' === $thousands_sep ) ? ',' : $thousands_sep;

		/* translators: $dec_point argument for https://secure.php.net/number_format, default is . */
		$decimal_point = __( 'number_format_decimal_point' );

		$this->number_format['decimal_point'] = ( 'number_format_decimal_point' === $decimal_point ) ? '.' : $decimal_point;

		// Set text direction.
		if ( isset( $GLOBALS['text_direction'] ) )
			$this->text_direction = $GLOBALS['text_direction'];
		/* translators: 'rtl' or 'ltr'. This sets the text direction for WordPress. */
		elseif ( 'rtl' == _x( 'ltr', 'text direction' ) )
			$this->text_direction = 'rtl';

		if ( 'rtl' === $this->text_direction && strpos( get_bloginfo( 'version' ), '-src' ) ) {
			$this->text_direction = 'ltr';
			add_action( 'all_admin_notices', array( $this, 'rtl_src_admin_notice' ) );
		}
	}

	public function rtl_src_admin_notice() {
		/* translators: %s: Name of the directory (build) */
		echo '<div class="error"><p>' . sprintf( __( 'The %s directory of the develop repository must be used for RTL.' ), '<code>build</code>' ) . '</p></div>';
	}

	public function get_weekday($weekday_number) {
		return $this->weekday[$weekday_number];
	}

	public function get_weekday_initial($weekday_name) {
		return $this->weekday_initial[$weekday_name];
	}

	public function get_weekday_abbrev($weekday_name) {
		return $this->weekday_abbrev[$weekday_name];
	}

	public function get_month($month_number) {
		return $this->month[zeroise($month_number, 2)];
	}

	public function get_month_abbrev($month_name) {
		return $this->month_abbrev[$month_name];
	}

	public function get_meridiem($meridiem) {
		return $this->meridiem[$meridiem];
	}

	public function register_globals() {
		$GLOBALS['weekday']         = $this->weekday;
		$GLOBALS['weekday_initial'] = $this->weekday_initial;
		$GLOBALS['weekday_abbrev']  = $this->weekday_abbrev;
		$GLOBALS['month']           = $this->month;
		$GLOBALS['month_abbrev']    = $this->month_abbrev;
	}

	public function is_rtl() {
		return 'rtl' == $this->text_direction;
	}

	public function _strings_for_pot() {
		/* translators: localized date format, see https://secure.php.net/date */
		__( 'F j, Y' );
		/* translators: localized time format, see https://secure.php.net/date */
		__( 'g:i a' );
		/* translators: localized date and time format, see https://secure.php.net/date */
		__( 'F j, Y g:i a' );
	}
}
